@@ -60,6 +60,9 @@ class TopTitleBarWidget(QWidget):
         lay = QGridLayout()
         lay.addWidget(self.__svgIconTitleWidget, 0, 0, 1, 2, alignment=align)
         lay.setContentsMargins(0, 0, 0, 0)
+        # todo
+        # set the spacing dynamically
+        lay.setSpacing(3)
         self.setLayout(lay)
 
     def setButtons(self, btnWidget, align=Qt.AlignRight):
@@ -76,6 +79,7 @@ class TopTitleBarWidget(QWidget):
         lay = self.layout()
         self.__separator.setFrameShape(QFrame.HLine)
         self.__separator.setFrameShadow(QFrame.Sunken)
+        self.__separator.setContentsMargins(0, 0, 0, 0)
         lay.addWidget(self.__separator, 1, 0, 1, 2)
 
     def getIconTitleWidget(self):
